@@ -33,9 +33,10 @@
 #  define KARCHIVE_DEPRECATED_NO_EXPORT KARCHIVE_NO_EXPORT KARCHIVE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KARCHIVE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KARCHIVE_NO_DEPRECATED
+#    define KARCHIVE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
